# PyEsoifier
A simple python script to esotericify your python code.

**Contrary to popular belief, using an obfuscator does not prevent your code from theft or reverse engineering. It only makes it harder to read. If someone really cared enough about your code to steal it, an obfuscator will not stop them.**
So, this project is just for fun and educational purposes. It shows you how you can push python to its limits.

## Structure
- `functions/` contains files which correspond to in-built functions in python. I've used a directory for this instead of just having everything in 1 file so that I can take you through my thinking process as I obfuscate the functions.
- `examples/` contains some examples of code. Files ending in `.out.py` are the obfuscated versions of the files ending in `.py`.
- `main.py` is the main file which contains the obfuscator code.


